@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd ;
-$Config::Model::Backend::Systemd::VERSION = '0.231.1';
+$Config::Model::Backend::Systemd::VERSION = '0.231.2';
 use strict;
 use warnings;
 use 5.010;
@@ -56,7 +56,7 @@ sub read {
             my ($unit_type) = ($file =~ $filter);
             $logger->debug( "registering unit $unit_type name $unit_name from $file (layered mode))");
             # force config_dir during init
-            $self->node->load(step => "$unit_type:$unit_name", check => $args{check} ) ;
+            $self->node->load(step => qq!$unit_type:"$unit_name"!, check => $args{check} ) ;
         }
     }
 
@@ -66,11 +66,11 @@ sub read {
         my $unit_name = $file->basename($filter);
         if ($file->realpath eq '/dev/null') {
             $logger->debug("unit $unit_type name $unit_name from $file is disabled");
-            $self->node->load(step => "$unit_type:$unit_name disable=1", check => $args{check} ) ;
+            $self->node->load(step => qq!$unit_type:"$unit_name" disable=1!, check => $args{check} ) ;
         }
         else {
             $logger->debug("registering unit $unit_type name $unit_name from $file");
-            $self->node->load(step => "$unit_type:$unit_name", check => $args{check} ) ;
+            $self->node->load(step => qq!$unit_type:"$unit_name"!, check => $args{check} ) ;
         }
     }
     return 1 ;
@@ -125,7 +125,7 @@ Config::Model::Backend::Systemd - R/W backend for systemd configurations files
 
 =head1 VERSION
 
-version 0.231.1
+version 0.231.2
 
 =head1 SYNOPSIS
 
