@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Systemd;
-$Config::Model::Systemd::VERSION = '0.231.1';
+$Config::Model::Systemd::VERSION = '0.231.2';
 use 5.10.1;
 
 use Config::Model 2.087;
@@ -29,7 +29,7 @@ Config::Model::Systemd - Editor and validator for systemd configuration files
 
 =head1 VERSION
 
-version 0.231.1
+version 0.231.2
 
 =head1 SYNOPSIS
 
@@ -116,7 +116,8 @@ by systemd project. This list is expected to be rather complete.
 
 The properties of these parameters are inferred from the description
 of the parameters and are probably less accurate. In case of errors,
-please log a bug.
+please L<log a bug|https://github.com/dod38fr/config-model-systemd/issues>.
+.
 
 =head1 TODO
 
@@ -200,7 +201,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Config-Model-Systemd>
+L<http://cpants.cpanauthors.org/dist/Config-Model-Systemd>
 
 =item *
 
